==> apache-sedona-1.5.1-src.tar.gz: apache-sedona-1.5.1-src/docs/community/contact.md <==
# Community

Every volunteer project obtains its strength from the people involved in it. We invite you to participate as much or as little as you choose.

You can participate in the community as follows:

* Use our project and provide a feedback.
* Provide us with the use-cases.
* Report bugs and submit patches.
* Contribute code and documentation.

## Community events

Everyone is welcome to join our community events. We have a community office hour every 4 weeks.

<iframe src="https://calendar.google.com/calendar/embed?src=c_ef7d54f5308a4b7f25ac33d0f7eeb54a3a7f115b689faf4d82425f3cb5ede935%40group.calendar.google.com&ctz=America%2FLos_Angeles" style="border: 0" width="800" height="600" frameborder="0" scrolling="no"></iframe>

## Twitter

[Apache Sedona@Twitter](https://twitter.com/ApacheSedona)

## Discord Server

![](https://dcbadge.vercel.app/api/server/9A3k5dEBsY)

Fill in the form below to join the Sedona Discord Server!

<script charset="utf-8" type="text/javascript" src="//js.hsforms.net/forms/embed/v2.js"></script>
<script>
  hbspt.forms.create({
    region: "na1",
    portalId: "44429642",
    formId: "4af794ab-318a-4d3b-ae8b-50143dbbdca5"
  });
</script>

## Mailing list

Get help using Sedona or contribute to the project on our mailing lists

[Sedona Mailing Lists](https://lists.apache.org/list.html?sedona.apache.org): [dev@sedona.apache.org](https://lists.apache.org/list.html?dev@sedona.apache.org): project development and general questions

* Please first subscribe and then post emails. To subscribe, please send an email (leave the subject and content blank) to dev-subscribe@sedona.apache.org

## Issue tracker

### Bug Reports

Found bug? Enter an issue in the [Sedona JIRA](https://issues.apache.org/jira/projects/SEDONA)

Before submitting an issue, please:

* Verify that the bug does in fact exist.
* Search the issue tracker to verify there is no existing issue reporting the bug you’ve found.
* Consider tracking down the bug yourself in the Sedona’s source and submitting a patch along with your bug report. This is a great time saver for the Sedona developers and helps ensure the bug will be fixed quickly.

### Feature Requests

Enhancement requests for new features are also welcome. The more concrete and rationale the request is, the greater the chance it will be incorporated into future releases.

Enter an issue in the [Sedona JIRA](https://issues.apache.org/jira/projects/SEDONA) or send an email to [dev@sedona.apache.org](https://lists.apache.org/list.html?dev@sedona.apache.org)

==> apache-sedona-1.5.2-src.tar.gz: apache-sedona-1.5.2-src/docs/community/contact.md <==
# Community

Every volunteer project obtains its strength from the people involved in it. We invite you to participate as much or as little as you choose.

You can participate in the community as follows:

* Use our project and provide a feedback.
* Provide us with the use-cases.
* Report bugs and submit patches.
* Contribute code and documentation.

## Community events

Everyone is welcome to join our community events. We have a community office hour every 4 weeks. Please import the event to your [Google Calendar](https://calendar.google.com/calendar/event?action=TEMPLATE&tmeid=NjI0cWgwcTZndnI1anAzYnFrNHY5Y2wyaTRfMjAyNDA0MDlUMTUwMDAwWiBjX2VmN2Q1NGY1MzA4YTRiN2YyNWFjMzNkMGY3ZWViNTRhM2E3ZjExNWI2ODlmYWY0ZDgyNDI1ZjNjYjVlZGU5MzVAZw&tmsrc=c_ef7d54f5308a4b7f25ac33d0f7eeb54a3a7f115b689faf4d82425f3cb5ede935%40group.calendar.google.com&scp=ALL).

## Twitter

[Apache Sedona@Twitter](https://twitter.com/ApacheSedona)

## Discord Server

[![](https://dcbadge.vercel.app/api/server/9A3k5dEBsY)](https://share.hsforms.com/1Ndql_ZigTdmLlVQc_d1o4gqga4q)

## Mailing list

Get help using Sedona or contribute to the project on our mailing lists

[Sedona Mailing Lists](https://lists.apache.org/list.html?sedona.apache.org): [dev@sedona.apache.org](https://lists.apache.org/list.html?dev@sedona.apache.org): project development and general questions

* Please first subscribe and then post emails. To subscribe, please send an email (leave the subject and content blank) to dev-subscribe@sedona.apache.org

## Issue tracker

### Bug Reports

Found bug? Enter an issue in the [Sedona JIRA](https://issues.apache.org/jira/projects/SEDONA)

Before submitting an issue, please:

* Verify that the bug does in fact exist.
* Search the issue tracker to verify there is no existing issue reporting the bug you’ve found.
* Consider tracking down the bug yourself in the Sedona’s source and submitting a patch along with your bug report. This is a great time saver for the Sedona developers and helps ensure the bug will be fixed quickly.

### Feature Requests

Enhancement requests for new features are also welcome. The more concrete and rationale the request is, the greater the chance it will be incorporated into future releases.

Enter an issue in the [Sedona JIRA](https://issues.apache.org/jira/projects/SEDONA) or email to [dev@sedona.apache.org](https://lists.apache.org/list.html?dev@sedona.apache.org)
